@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.24';
+$VERSION = '5.25';
 
 =head1 NAME
 
@@ -25,7 +25,7 @@ require Exporter;
 @ISA = qw(Exporter);
 
 %EXPORT_TAGS = (
-    'all' => [ qw( GetGroupID UserInGroup GroupSelect GroupSelectMulti ) ]
+    'all' => [ qw( GetGroupID UserInGroup UserGroups GroupSelect GroupSelectMulti ) ]
 );
 
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -42,6 +42,11 @@ use Labyrinth::Session;
 use Labyrinth::Support;
 use Labyrinth::Variables;
 
+# -------------------------------------
+# Variables
+
+my %InGroup;
+
 # -------------------------------------
 # The Subs
 
@@ -58,6 +63,10 @@ Returns the ID of the specific group.
 Checks whether the specified user (or current user) is in the specified group
 Returns 1 if true, otherwise 0 for false.
 
+=item UserGroups()
+
+For the current user login, return the list of groups they are associated with.
+
 =item GroupSelect([$opt])
 
 Provides the XHTML code for a single select dropdown box. Pass the id of a
@@ -73,16 +82,14 @@ number of rows you require.
 =cut
 
 sub GetGroupID {
-    my $name = shift;
+    my $name = shift || return;
     my @rows = $dbi->GetQuery('array','GetGroupID',$name);
     return  unless(@rows);
     return $rows[0]->[0];
 }
 
-my %InGroup;
-
 sub UserInGroup {
-    my $groupid = shift;
+    my $groupid = shift || return;
     my $userid  = shift || $tvars{loginid};
     return 0    unless($groupid && $userid);
 
@@ -91,6 +98,33 @@ sub UserInGroup {
     return 0;
 }
 
+sub UserGroups {
+    my $userid  = shift || $tvars{loginid};
+    my (%groups,@grps);
+    my @rows = $dbi->GetQuery('hash','AllGroupIndex');
+    foreach (@rows) {
+        # a user link, but not our user
+        next    if($_->{type} == 1 && $_->{linkid} ne $userid);
+        
+        if($_->{type} == 1) {
+            push @grps, $_->{groupid};
+        } else {
+            push @{$groups{$_->{linkid}}}, $_->{groupid};
+        }
+    }
+    my @list = ();
+    while(@grps) {
+        my $g = shift @grps;
+        push @list, $g;
+        next    unless($groups{$g});
+        push @grps, @{$groups{$g}};
+        delete $groups{$g};
+    }
+    my %hash = map {$_ => 1} @list;
+    my $grps = join(",",keys %hash);
+    return $grps;
+}
+
 sub GroupSelect {
     my $opt = shift;
     my @rows = $dbi->GetQuery('hash','AllGroups');
